@@ -1,3 +1,3 @@
-from .experiment_messages import StartExperimentMessage
+from .experiment_messages import *
 from .experiment_service import ExperimentService
-from .experiment_client import ExperimentClient
\ No newline at end of file
+from .experiment_client import ExperimentClient
